Learn R Programming

nflreadr (version 1.4.0)

load_espn_qbr: Load ESPN's QBR

Description

Load ESPN's QBR

Usage

load_espn_qbr(
  league = c("nfl", "college"),
  seasons = most_recent_season(),
  summary_type = c("season", "weekly")
)

Value

a tibble of season-level injury report data.

Arguments

league

One of "nfl" or "college", defaults to "nfl"

seasons

a numeric vector of seasons to return, data available since 2006. Defaults to latest season available. TRUE will select all seasons.

summary_type

One of "season" or "weekly", defaults to season

See Also

https://nflreadr.nflverse.com/articles/dictionary_espn_qbr.html for a web version of the dictionary

dictionary_espn_qbr for the data dictionary as bundled within the package

Issues with this data should be filed here: https://github.com/nflverse/espnscrapeR-data

Examples

Run this code
.for_cran()
# \donttest{
    load_espn_qbr("nfl",2020)
# }

Run the code above in your browser using DataLab