A helper function to choose the most recent season available for a given dataset
most_recent_season(roster = FALSE)get_latest_season(roster = FALSE)
get_current_season(roster = FALSE)
most recent season (a four digit numeric)
Either TRUE or FALSE.
If TRUE, will return current year after March 15th, otherwise previous year.
If FALSE, will return current year on or after Thursday following Labor Day,
i.e. Thursday after the first Monday in September. Otherwise previous year.
Other Date utils:
get_current_week()