powered by
Load ESPN's QBR
load_espn_qbr( league = c("nfl", "college"), seasons = most_recent_season(), summary_type = c("season", "weekly") )
a tibble of season-level injury report data.
One of "nfl" or "college", defaults to "nfl"
a numeric vector of seasons to return, data available since 2006. Defaults to latest season available. TRUE will select all seasons.
One of "season" or "weekly", defaults to season
https://nflreadr.nflverse.com/articles/dictionary_espn_qbr.html for a web version of the dictionary
dictionary_espn_qbr for the data dictionary as bundled within the package
dictionary_espn_qbr
Issues with this data should be filed here: https://github.com/nflverse/espnscrapeR-data
.for_cran() # \donttest{ load_espn_qbr("nfl",2020) # }
Run the code above in your browser using DataLab